==> libosip2-2.0.6.tar.gz: libosip2-2.0.6/debian/manpage.sgml.ex <==
<!doctype refentry PUBLIC "-//OASIS//DTD DocBook V4.1//EN" [


  <!ENTITY dhfirstname "<firstname>Aymeric</firstname>">
  <!ENTITY dhsurname   "<surname>MOIZARD</surname>">
  <!ENTITY dhdate      "<date>May 15, 2002</date>">
  <!ENTITY dhsection   "<manvolnum>SECTION</manvolnum>">
  <!ENTITY dhemail     "<email>jack@atosc.org</email>">
  <!ENTITY dhusername  "Aymeric Moizard">
  <!ENTITY dhucpackage "<refentrytitle>LIBOSIP</refentrytitle>">
  <!ENTITY dhpackage   "libosip">

  <!ENTITY debian      "<productname>Debian</productname>">
  <!ENTITY gnu         "<acronym>GNU</acronym>">
]>

<refentry>
  <refentryinfo>
    <address>
      &dhemail;
    </address>
    <author>
      &dhfirstname;
      &dhsurname;
    </author>
    <copyright>
      <year>2001</year>
      <holder>&dhusername;</holder>
    </copyright>
    &dhdate;
  </refentryinfo>
  <refmeta>
    &dhucpackage;

    &dhsection;
  </refmeta>
  <refnamediv>
    <refname>&dhpackage;</refname>

    <refpurpose>The GNU oSIP library is a low layer SIP implementation.
    </refpurpose>
  </refnamediv>
  <refsynopsisdiv>
    <cmdsynopsis>
      <command>-losip</command>
      
      <arg><option>The url, SIP and SDP parsers</option></arg>
      </cmdsynopsis>
    <cmdsynopsis>
      <command>-lfsmtl</command>
      <arg><option>The SIP transaction manager, the dialog manager</option></arg>
    </cmdsynopsis>
  </refsynopsisdiv>
  <refsect1>
    <title>DESCRIPTION</title>

    <para>This manual page documents briefly the
      <command>&dhpackage;</command> library.</para>

    <para>API reference & FAQ can be found at http://www.fsf.org/software/osip/</para>

<!--    <para><command>&dhpackage;</command> is a program that...</para>
-->

  </refsect1>
  <refsect1>
<!--
    <title>OPTIONS</title>

    <para>These programs follow the usual GNU command line syntax,
      with long options starting with two dashes (`-').  A summary of
      options is included below.  For a complete description, see the
      <application>Info</application> files.</para>

    <variablelist>
      <varlistentry>
        <term><option>-h</option>
          <option>-help</option>
        </term>
        <listitem>
          <para>Show summary of options.</para>
        </listitem>
      </varlistentry>
      <varlistentry>
        <term><option>-v</option>
          <option>-version</option>
        </term>
        <listitem>
          <para>Show version of program.</para>
        </listitem>
      </varlistentry>
    </variablelist>

-->
  </refsect1>
  <refsect1>
    <title>SEE ALSO</title>
<!--
    <para>bar (1), baz (1).</para>

    <para>The programs are documented fully by <citetitle>The Rise and
      Fall of a Fooish Bar</citetitle> available via the
      <application>Info</application> system.</para>
-->
  </refsect1>
  <refsect1>
    <title>AUTHOR</title>

    <para>This manual page was written by &dhusername; &dhemail; for
      the &debian; system (but may be used by others).  Permission is
      granted to copy, distribute and/or modify this document under
      the terms of the <acronym>GNU</acronym> Free Documentation
      License, Version 1.1 or any later version published by the Free
      Software Foundation; with no Invariant Sections, no Front-Cover
      Texts and no Back-Cover Texts.</para>

  </refsect1>
</refentry>

<!-- Keep this comment at the end of the file
Local variables:
mode: sgml
sgml-omittag:t
sgml-shorttag:t
sgml-minimize-attributes:nil
sgml-always-quote-attributes:t
sgml-indent-step:2
sgml-indent-data:t
sgml-parent-document:nil
sgml-default-dtd-file:nil
sgml-exposed-tags:nil
sgml-local-catalogs:nil
sgml-local-ecat-files:nil
End:
-->

==> libosip2-3.0.1.tar.gz: libosip2-3.0.1/debian/manpage.sgml.ex <==
<!doctype refentry PUBLIC "-//OASIS//DTD DocBook V4.1//EN" [


  <!ENTITY dhfirstname "<firstname>Aymeric</firstname>">
  <!ENTITY dhsurname   "<surname>MOIZARD</surname>">
  <!ENTITY dhdate      "<date>May 15, 2002</date>">
  <!ENTITY dhsection   "<manvolnum>SECTION</manvolnum>">
  <!ENTITY dhemail     "<email>jack@atosc.org</email>">
  <!ENTITY dhusername  "Aymeric Moizard">
  <!ENTITY dhucpackage "<refentrytitle>LIBOSIP</refentrytitle>">
  <!ENTITY dhpackage   "libosip">

  <!ENTITY debian      "<productname>Debian</productname>">
  <!ENTITY gnu         "<acronym>GNU</acronym>">
]>

<refentry>
  <refentryinfo>
    <address>
      &dhemail;
    </address>
    <author>
      &dhfirstname;
      &dhsurname;
    </author>
    <copyright>
      <year>2001</year>
      <holder>&dhusername;</holder>
    </copyright>
    &dhdate;
  </refentryinfo>
  <refmeta>
    &dhucpackage;

    &dhsection;
  </refmeta>
  <refnamediv>
    <refname>&dhpackage;</refname>

    <refpurpose>The GNU oSIP library is a low layer SIP implementation.
    </refpurpose>
  </refnamediv>
  <refsynopsisdiv>
    <cmdsynopsis>
      <command>-losip</command>
      
      <arg><option>The url, SIP and SDP parsers</option></arg>
      </cmdsynopsis>
    <cmdsynopsis>
      <command>-lfsmtl</command>
      <arg><option>The SIP transaction manager, the dialog manager</option></arg>
    </cmdsynopsis>
  </refsynopsisdiv>
  <refsect1>
    <title>DESCRIPTION</title>

    <para>This manual page documents briefly the
      <command>&dhpackage;</command> library.</para>

    <para>API reference & FAQ can be found at http://www.gnu.org/software/osip/</para>

<!--    <para><command>&dhpackage;</command> is a program that...</para>
-->

  </refsect1>
  <refsect1>
<!--
    <title>OPTIONS</title>

    <para>These programs follow the usual GNU command line syntax,
      with long options starting with two dashes (`-').  A summary of
      options is included below.  For a complete description, see the
      <application>Info</application> files.</para>

    <variablelist>
      <varlistentry>
        <term><option>-h</option>
          <option>-help</option>
        </term>
        <listitem>
          <para>Show summary of options.</para>
        </listitem>
      </varlistentry>
      <varlistentry>
        <term><option>-v</option>
          <option>-version</option>
        </term>
        <listitem>
          <para>Show version of program.</para>
        </listitem>
      </varlistentry>
    </variablelist>

-->
  </refsect1>
  <refsect1>
    <title>SEE ALSO</title>
<!--
    <para>bar (1), baz (1).</para>

    <para>The programs are documented fully by <citetitle>The Rise and
      Fall of a Fooish Bar</citetitle> available via the
      <application>Info</application> system.</para>
-->
  </refsect1>
  <refsect1>
    <title>AUTHOR</title>

    <para>This manual page was written by &dhusername; &dhemail; for
      the &debian; system (but may be used by others).  Permission is
      granted to copy, distribute and/or modify this document under
      the terms of the <acronym>GNU</acronym> Free Documentation
      License, Version 1.1 or any later version published by the Free
      Software Foundation; with no Invariant Sections, no Front-Cover
      Texts and no Back-Cover Texts.</para>

  </refsect1>
</refentry>

<!-- Keep this comment at the end of the file
Local variables:
mode: sgml
sgml-omittag:t
sgml-shorttag:t
sgml-minimize-attributes:nil
sgml-always-quote-attributes:t
sgml-indent-step:2
sgml-indent-data:t
sgml-parent-document:nil
sgml-default-dtd-file:nil
sgml-exposed-tags:nil
sgml-local-catalogs:nil
sgml-local-ecat-files:nil
End:
-->
